@@ -80,15 +80,20 @@ PROFILE (static GTimer *timer = NULL);
 struct _GeditDocumentPrivate
 {
 	gchar		    *uri;
-	gint 		     untitled_number;	
+	gint 		     untitled_number;
 
 	gchar		    *encoding;
 
+	gchar		    *mime_type;
+
 	gchar		    *last_searched_text;
 	gchar		    *last_replace_text;
 	gboolean  	     last_search_was_case_sensitive;
 	gboolean  	     last_search_was_entire_word;
 
+	gboolean             auto_save;
+	gint                 auto_save_interval;
+
 	guint		     auto_save_timeout;
 	gboolean	     last_save_was_manually; 
 
@@ -132,8 +137,7 @@ static gboolean	gedit_document_save_as_real (GeditDocument *doc, const gchar *ur
 					     gboolean create_backup_copy, GError **error);
 static void gedit_document_set_uri (GeditDocument* doc, const gchar* uri);
 
-static gboolean gedit_document_auto_save (GeditDocument *doc, GError **error);
-static gboolean gedit_document_auto_save_timeout (GeditDocument *doc);
+static gboolean gedit_document_auto_save (GeditDocument *doc);
 
 static GtkTextBufferClass *parent_class 	= NULL;
 static guint document_signals[LAST_SIGNAL] 	= { 0 };
@@ -308,6 +312,8 @@ gedit_document_init (GeditDocument *document)
 	document->priv->uri = NULL;
 	document->priv->untitled_number = 0;
 
+	document->priv->mime_type = g_strdup ("text/plain");
+
 	document->priv->readonly = FALSE;
 
 	document->priv->last_save_was_manually = TRUE;
@@ -323,6 +329,13 @@ gedit_document_init (GeditDocument *document)
 					    gedit_prefs_manager_get_undo_actions_limit ());
 
 	gtk_source_buffer_set_check_brackets (GTK_SOURCE_BUFFER (document), FALSE);
+
+	document->priv->auto_save = gedit_prefs_manager_get_auto_save ();
+	document->priv->auto_save = (document->priv->auto_save != FALSE);
+
+	document->priv->auto_save_interval = gedit_prefs_manager_get_auto_save_interval ();
+	if (document->priv->auto_save_interval <= 0)
+		document->priv->auto_save_interval = GPM_DEFAULT_AUTO_SAVE_INTERVAL;
 }
 
 static void
@@ -393,6 +406,7 @@ gedit_document_finalize (GObject *object)
 	}
 
 	g_free (document->priv->uri);
+	g_free (document->priv->mime_type);
 	g_free (document->priv->last_searched_text);
 	g_free (document->priv->last_replace_text);
 	g_free (document->priv->encoding);
@@ -466,18 +480,14 @@ gedit_document_new_with_uri (const gchar          *uri,
 void 		
 gedit_document_set_readonly (GeditDocument *document, gboolean readonly)
 {
-	gboolean auto_save;
-	
 	gedit_debug (DEBUG_DOCUMENT, "");
 
 	g_return_if_fail (document != NULL);
 	g_return_if_fail (document->priv != NULL);
 
-	auto_save = gedit_prefs_manager_get_auto_save ();
-	
 	if (readonly) 
 	{
-		if (auto_save && (document->priv->auto_save_timeout > 0))
+		if (document->priv->auto_save_timeout > 0)
 		{
 			gedit_debug (DEBUG_DOCUMENT, "Remove autosave timeout");
 
@@ -487,18 +497,15 @@ gedit_document_set_readonly (GeditDocument *document, gboolean readonly)
 	}
 	else
 	{
-		if (auto_save && (document->priv->auto_save_timeout <= 0))
+		if (document->priv->auto_save && 
+		    (document->priv->auto_save_timeout <= 0) && 
+                    !gedit_document_is_untitled (document))
 		{
-			gint auto_save_interval;
-			
 			gedit_debug (DEBUG_DOCUMENT, "Install autosave timeout");
 
-			auto_save_interval = 
-				gedit_prefs_manager_get_auto_save_interval ();
-				
 			document->priv->auto_save_timeout = g_timeout_add 
-				(auto_save_interval * 1000 * 60,
-		 		 (GSourceFunc)gedit_document_auto_save_timeout,
+				(document->priv->auto_save_interval * 1000 * 60,
+		 		 (GSourceFunc)gedit_document_auto_save,
 		  		 document);		
 		}
 	}
@@ -556,6 +563,7 @@ gedit_document_real_loaded (GeditDocument *document, const GError *error)
 	g_return_if_fail (document->priv->uri != NULL);
 
 	/* FIXME: commented since it does not work as expected - Paolo */
+	
 	/*
 	data = gedit_metadata_manager_get (document->priv->uri,
 					   "position");
@@ -711,22 +719,34 @@ gedit_document_io_error_quark (void)
 }
 
 static gboolean
-gedit_document_auto_save_timeout (GeditDocument *doc)
+gedit_document_auto_save (GeditDocument *doc)
 {
+	const GeditEncoding *encoding;
+	gboolean create_backup;
 	GError *error = NULL;
 
 	gedit_debug (DEBUG_DOCUMENT, "");
 
+	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), FALSE);
 	g_return_val_if_fail (!gedit_document_is_readonly (doc), FALSE);
-
-	/* Remove timeout if now auto_save is FALSE */
-	if (!gedit_prefs_manager_get_auto_save ()) 
-		return FALSE;
+	g_return_val_if_fail (!gedit_document_is_untitled (doc), FALSE);
 
 	if (!gedit_document_get_modified (doc))
 		return TRUE;
 
-	gedit_document_auto_save (doc, &error);
+	encoding = gedit_document_get_encoding (doc);
+	create_backup = gedit_prefs_manager_get_create_backup_copy ();
+
+	/* we save a backup just if backups are enabled and if the last
+	 * save was manual.
+	 */
+	if (gedit_document_save_as_real (doc, doc->priv->uri, encoding,
+					 doc->priv->last_save_was_manually && create_backup,
+					 &error))
+	{
+		doc->priv->last_save_was_manually = FALSE;
+		g_get_current_time (&doc->priv->time_of_last_save_or_load);
+	}
 
 	if (error) 
 	{
@@ -739,27 +759,6 @@ gedit_document_auto_save_timeout (GeditDocument *doc)
 	return TRUE;
 }
 
-static gboolean
-gedit_document_auto_save (GeditDocument* doc, GError **error)
-{
-	const GeditEncoding *encoding;
-	
-	gedit_debug (DEBUG_DOCUMENT, "");
-	
-	g_return_val_if_fail (doc != NULL, FALSE);
-
-	encoding = gedit_document_get_encoding (doc);
-		
-	if (gedit_document_save_as_real (doc, doc->priv->uri, encoding,
-					 doc->priv->last_save_was_manually, NULL))
-	{
-		doc->priv->last_save_was_manually = FALSE;
-		g_get_current_time (&doc->priv->time_of_last_save_or_load);
-	}
-
-	return TRUE;
-}
-
 /* NOTE: thie function frees file_contents */
 static gboolean
 update_document_contents (GeditDocument        *doc, 
@@ -1086,6 +1085,12 @@ get_info_cb (GnomeVFSAsyncHandle *handle,
 		return;
 	}
 
+	/* store the mime type */
+	g_free (doc->priv->mime_type);
+	doc->priv->mime_type = info_result->file_info->mime_type ?
+			       g_strdup (info_result->file_info->mime_type) :
+			       g_strdup ("text/plain");
+
 	if (info_result->file_info->valid_fields & GNOME_VFS_FILE_INFO_FIELDS_SIZE)
 	{
 		doc->priv->temp_size = (gulong)info_result->file_info->size;
@@ -1127,6 +1132,8 @@ load_local (GeditDocument *doc)
 	res = gnome_vfs_get_file_info (doc->priv->temp_uri,
 				       info,
 				       GNOME_VFS_FILE_INFO_DEFAULT |
+				       GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+				       GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE |
 				       GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
 	if (res != GNOME_VFS_OK)
@@ -1177,6 +1184,12 @@ load_local (GeditDocument *doc)
 		return FALSE;
 	}
 
+	/* store the mime type */
+	g_free (doc->priv->mime_type);
+	doc->priv->mime_type = info->mime_type ?
+			       g_strdup (info->mime_type) :
+			       g_strdup ("text/plain");
+
 	gnome_vfs_file_info_unref (info);
 
 	res = gnome_vfs_read_entire_file (doc->priv->temp_uri, 
@@ -1327,6 +1340,8 @@ gedit_document_load (GeditDocument        *doc,
 		gnome_vfs_async_get_file_info (&doc->priv->info_handle,
 					       uri_list,
 					       GNOME_VFS_FILE_INFO_DEFAULT |
+					       GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+					       GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE |
 					       GNOME_VFS_FILE_INFO_FOLLOW_LINKS,
 					       GNOME_VFS_PRIORITY_MAX,
 					       get_info_cb,
@@ -1362,7 +1377,7 @@ gedit_document_load_from_stdin (GeditDocument* doc, GError **error)
 		const GeditEncoding *encoding;
 		gchar *converted_text;
 
-		if (gedit_encoding_get_current () != gedit_encoding_get_utf8 ())
+		if (gedit_encoding_get_current () == gedit_encoding_get_utf8 ())
 		{
 			if (g_utf8_validate (stdin_data, -1, NULL))
 			{
@@ -1444,34 +1459,10 @@ gedit_document_is_untouched (const GeditDocument *doc)
 		(!gtk_text_buffer_get_modified (GTK_TEXT_BUFFER (doc)));
 }
 
-/* FIXME: Remove this function when gnome-vfs will add an equivalent public
-   function - Paolo (Mar 05, 2004) */
-static gchar *
-get_slow_mime_type (const char *text_uri)
-{
-	GnomeVFSFileInfo *info;
-	char *mime_type;
-	GnomeVFSResult result;
-
-	info = gnome_vfs_file_info_new ();
-	result = gnome_vfs_get_file_info (text_uri, info,
-					  GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
-					  GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE |
-					  GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
-	if (info->mime_type == NULL || result != GNOME_VFS_OK) {
-		mime_type = NULL;
-	} else {
-		mime_type = g_strdup (info->mime_type);
-	}
-	gnome_vfs_file_info_unref (info);
-
-	return mime_type;
-}
-
 static void
 gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 {
-	GtkSourceLanguage *language;
+	GtkSourceLanguage *language = NULL;
 	gchar *data;
 	
 	gedit_debug (DEBUG_DOCUMENT, "");
@@ -1499,52 +1490,36 @@ gedit_document_set_uri (GeditDocument* doc, const gchar* uri)
 	{
 		gedit_debug (DEBUG_DOCUMENT, "Language: %s", data);
 
-		if (strcmp (data, "_NORMAL_") == 0)
-			language = NULL;
-		else
+		if (strcmp (data, "_NORMAL_") != 0)
 			language = gedit_languages_manager_get_language_from_id (
 						gedit_get_languages_manager (),
 						data);
 
-		gedit_document_set_language (doc, language);
-
 		g_free (data);
 	}
 	else
 	{
-		gchar *mime_type;
-
-		mime_type = get_slow_mime_type (uri);
-	
-		if (mime_type != NULL)
+		if (doc->priv->mime_type != NULL)
 		{
-			GtkSourceLanguage *language;
-			
-			gedit_debug (DEBUG_DOCUMENT, "MIME-TYPE: %s", mime_type);
-
 			language = gtk_source_languages_manager_get_language_from_mime_type (
 						gedit_get_languages_manager (),
-						mime_type);
-	
-			gedit_document_set_language (doc, language);
-	
-			g_free (mime_type);
+						doc->priv->mime_type);
 		}
 		else
 		{
-			g_warning ("Couldn't get mime type for file `%s'", uri);
+			/* should never happen */
+			g_warning ("gedit document %s has NULL mime_type", uri);
 		}
-
-		
 	}
 
+	gedit_document_set_language (doc, language);
+
 	g_signal_emit (G_OBJECT (doc), document_signals[NAME_CHANGED], 0);
 }
 	
 gboolean 
 gedit_document_save (GeditDocument *doc, GError **error)
 {	
-	gboolean auto_save;
 	gboolean create_backup_copy;
 	const GeditEncoding *encoding;
 	
@@ -1560,16 +1535,12 @@ gedit_document_save (GeditDocument *doc, GError **error)
 	encoding = gedit_document_get_encoding (doc);
 	g_return_val_if_fail (encoding != NULL, FALSE);
 	
-	auto_save = gedit_prefs_manager_get_auto_save ();
 	create_backup_copy = gedit_prefs_manager_get_create_backup_copy ();
 		
-	if (auto_save) 
+	if (doc->priv->auto_save_timeout > 0)
 	{
-		if (doc->priv->auto_save_timeout > 0)
-		{
-			g_source_remove (doc->priv->auto_save_timeout);
-			doc->priv->auto_save_timeout = 0;
-		}
+		g_source_remove (doc->priv->auto_save_timeout);
+		doc->priv->auto_save_timeout = 0;
 	}
 	
 	ret = gedit_document_save_as_real (doc, 
@@ -1584,13 +1555,10 @@ gedit_document_save (GeditDocument *doc, GError **error)
 		g_get_current_time (&doc->priv->time_of_last_save_or_load);
 	}
 
-	if (auto_save && (doc->priv->auto_save_timeout <= 0)) 
+	if (doc->priv->auto_save && (doc->priv->auto_save_timeout <= 0)) 
 	{
-		gint auto_save_interval = 
-			gedit_prefs_manager_get_auto_save_interval ();
-
 		doc->priv->auto_save_timeout =
-			g_timeout_add (auto_save_interval * 1000 * 60,
+			g_timeout_add (doc->priv->auto_save_interval * 1000 * 60,
 				       (GSourceFunc) gedit_document_auto_save, 
 				       doc);
 	}
@@ -1602,10 +1570,10 @@ gboolean
 gedit_document_save_as (GeditDocument* doc, const gchar *uri, 
 			const GeditEncoding *encoding, GError **error)
 {	
-	gboolean auto_save;
-	
+	gboolean create_backup;
+
 	gboolean ret = FALSE;
-	
+
 	gedit_debug (DEBUG_DOCUMENT, "");
 
 	g_return_val_if_fail (doc != NULL, FALSE);
@@ -1615,19 +1583,15 @@ gedit_document_save_as (GeditDocument* doc, const gchar *uri,
 	if (encoding == NULL)
 		encoding = gedit_document_get_encoding (doc);
 
-	auto_save = gedit_prefs_manager_get_auto_save ();
+	create_backup = gedit_prefs_manager_get_create_backup_copy ();
 
-	if (auto_save) 
+	if (doc->priv->auto_save_timeout > 0)
 	{
-
-		if (doc->priv->auto_save_timeout > 0)
-		{
-			g_source_remove (doc->priv->auto_save_timeout);
-			doc->priv->auto_save_timeout = 0;
-		}
+		g_source_remove (doc->priv->auto_save_timeout);
+		doc->priv->auto_save_timeout = 0;
 	}
 
-	if (gedit_document_save_as_real (doc, uri, encoding, TRUE, error))
+	if (gedit_document_save_as_real (doc, uri, encoding, create_backup, error))
 	{
 		gedit_document_set_uri (doc, uri);
 		gedit_document_set_readonly (doc, FALSE);
@@ -1638,15 +1602,12 @@ gedit_document_save_as (GeditDocument* doc, const gchar *uri,
 		gedit_document_set_encoding (doc, encoding);
 			
 		ret = TRUE;
-	}		
+	}
 
-	if (auto_save && (doc->priv->auto_save_timeout <= 0)) 
+	if (doc->priv->auto_save && (doc->priv->auto_save_timeout <= 0)) 
 	{
-		gint auto_save_interval =
-			gedit_prefs_manager_get_auto_save_interval ();
-		
 		doc->priv->auto_save_timeout =
-			g_timeout_add (auto_save_interval * 1000 * 60,
+			g_timeout_add (doc->priv->auto_save_interval * 1000 * 60,
 				       (GSourceFunc)gedit_document_auto_save, doc);
 	}
 
@@ -1744,10 +1705,33 @@ follow_symlinks (const gchar *filename, GError **error)
 	return NULL;
 }
 
+/* FIXME: Remove this function when gnome-vfs will add an equivalent public
+   function - Paolo (Mar 05, 2004) */
+static gchar *
+get_slow_mime_type (const char *text_uri)
+{
+	GnomeVFSFileInfo *info;
+	char *mime_type;
+	GnomeVFSResult result;
+
+	info = gnome_vfs_file_info_new ();
+	result = gnome_vfs_get_file_info (text_uri, info,
+					  GNOME_VFS_FILE_INFO_GET_MIME_TYPE |
+					  GNOME_VFS_FILE_INFO_FORCE_SLOW_MIME_TYPE |
+					  GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+	if (info->mime_type == NULL || result != GNOME_VFS_OK) {
+		mime_type = NULL;
+	} else {
+		mime_type = g_strdup (info->mime_type);
+	}
+	gnome_vfs_file_info_unref (info);
+
+	return mime_type;
+}
+
 /* FIXME: define new ERROR_CODE and remove the error 
  * strings from here -- Paolo
  */
-
 static gboolean	
 gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEncoding *encoding,
 			     gboolean create_backup_copy, GError **error)
@@ -1768,6 +1752,7 @@ gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEn
 	gboolean add_cr;
 	GtkTextIter start_iter;
 	GtkTextIter end_iter;
+	gchar *detected_mime;
 	
 	gedit_debug (DEBUG_DOCUMENT, "");
 
@@ -2013,6 +1998,11 @@ gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEn
 
 	gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc), FALSE);
 
+	/* update the mime type */
+	detected_mime = get_slow_mime_type (uri);
+	g_free (doc->priv->mime_type);
+	doc->priv->mime_type = detected_mime ? detected_mime : g_strdup ("text/plain");
+
 	retval = TRUE;
 
 	/* Done */
@@ -2029,6 +2019,19 @@ gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEn
 	return retval;
 }
 
+const gchar *
+gedit_document_get_mime_type (const GeditDocument* doc)
+{
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_val_if_fail (doc != NULL, FALSE);
+	g_return_val_if_fail (doc->priv != NULL, FALSE);
+
+	g_return_val_if_fail (doc->priv->mime_type != NULL, "text/plain");
+
+	return doc->priv->mime_type;
+}
+
 gboolean	
 gedit_document_is_untitled (const GeditDocument* doc)
 {
@@ -2619,3 +2622,79 @@ gedit_document_get_seconds_since_last_save_or_load (GeditDocument *doc)
 	return (current_time.tv_sec - doc->priv->time_of_last_save_or_load.tv_sec);
 }
 
+void
+gedit_document_enable_auto_save (GeditDocument *doc, gboolean enable)
+{
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+
+	enable = (enable != FALSE);
+
+	if (doc->priv->auto_save == enable)
+		return;
+
+	doc->priv->auto_save = enable;
+
+	if (doc->priv->auto_save && 
+	    (doc->priv->auto_save_timeout <= 0) && 
+	    !gedit_document_is_untitled (doc) &&
+	    !gedit_document_is_readonly (doc))
+	{
+		gedit_debug (DEBUG_DOCUMENT, "Install autosave timeout");
+
+		doc->priv->auto_save_timeout = g_timeout_add 
+							(doc->priv->auto_save_interval * 1000 * 60,
+			 		 		 (GSourceFunc)gedit_document_auto_save,	
+					  		 doc);		
+
+		return;
+	}
+	
+	if (!doc->priv->auto_save && (doc->priv->auto_save_timeout > 0))
+	{
+		gedit_debug (DEBUG_DOCUMENT, "Remove autosave timeout");
+
+		g_source_remove (doc->priv->auto_save_timeout);
+		doc->priv->auto_save_timeout = 0;
+
+		return;
+	}
+
+	g_return_if_fail ((!doc->priv->auto_save && (doc->priv->auto_save_timeout <= 0)) || 
+			  gedit_document_is_untitled (doc) || gedit_document_is_readonly (doc));
+}
+
+void
+gedit_document_set_auto_save_interval (GeditDocument *doc, gint interval)
+{
+	gedit_debug (DEBUG_DOCUMENT, "");
+
+	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
+	g_return_if_fail (interval > 0);
+
+	if (doc->priv->auto_save_interval == interval)
+		return;
+	
+	doc->priv->auto_save_interval = interval;
+		
+	if (!doc->priv->auto_save)
+		return;
+
+	if (doc->priv->auto_save_timeout > 0)
+	{
+		gedit_debug (DEBUG_DOCUMENT, "Remove autosave timeout");
+
+		g_source_remove (doc->priv->auto_save_timeout);
+	
+		gedit_debug (DEBUG_DOCUMENT, "Install new autosave timeout");
+
+		g_return_if_fail (!gedit_document_is_untitled (doc));
+		g_return_if_fail (!gedit_document_is_readonly (doc));
+
+		doc->priv->auto_save_timeout = g_timeout_add 
+						(doc->priv->auto_save_interval * 1000 * 60,
+		 		 		 (GSourceFunc)gedit_document_auto_save,	
+				  		 doc);		
+	}
+}
