@@ -46,24 +46,12 @@
 #include <config.h>
 #endif
 
-#include "gedit-file-selector-util.h"
-
 #include <string.h>
-#include <unistd.h>
-#include <errno.h>
-
-#include <bonobo/bonobo-event-source.h>
-#include <bonobo/bonobo-exception.h>
-#include <bonobo/bonobo-widget.h>
-
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
-
-#include <bonobo/bonobo-i18n.h>
-
 #include <libgnomevfs/gnome-vfs.h>
-#include <eel/eel-vfs-extensions.h>
-#include <eel/eel-alert-dialog.h>
 
+#include "gedit-file-selector-util.h"
 #include "gedit-utils.h"
 #include "gedit-encodings-option-menu.h"
 
@@ -86,24 +74,18 @@ typedef enum {
 static gboolean
 replace_dialog (GtkWindow *parent,
 		const gchar *primary_message,
-		const gchar *file_name,
+		const gchar *uri,
 		const gchar *secondary_message)
 {
-	GtkWidget *msgbox;
-	AtkObject *obj;
+	GtkWidget *dialog;
 	gint ret;
 	gchar *full_formatted_uri;
        	gchar *uri_for_display	;
-	gchar *uri;
 	gchar *message_with_uri;
 
-	uri = eel_make_uri_from_shell_arg (file_name);
-	g_return_val_if_fail (uri != NULL, FALSE);
-
 	full_formatted_uri = gnome_vfs_format_uri_for_display (uri);
 	g_return_val_if_fail (full_formatted_uri != NULL, FALSE);
-	g_free (uri);
-	
+
 	/* Truncate the URI so it doesn't get insanely wide. Note that even
 	 * though the dialog uses wrapped text, if the URI doesn't contain
 	 * white space then the text-wrapping code is too stupid to wrap it.
@@ -115,51 +97,49 @@ replace_dialog (GtkWindow *parent,
 	message_with_uri = g_strdup_printf (primary_message, uri_for_display);
 	g_free (uri_for_display);
 
-	msgbox = eel_alert_dialog_new (parent,
-				       GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-				       GTK_MESSAGE_QUESTION,
-				       GTK_BUTTONS_NONE,
-				       message_with_uri,
-				       secondary_message,
-				       NULL);
+	dialog = gtk_message_dialog_new (parent,
+					 GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+					 GTK_MESSAGE_QUESTION,
+					 GTK_BUTTONS_NONE,
+					 message_with_uri);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  secondary_message);
+
 	g_free (message_with_uri);
 
-	/* Add Cancel button */
-	gtk_dialog_add_button (GTK_DIALOG (msgbox), 
-			GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
+	gtk_dialog_add_button (GTK_DIALOG (dialog), 
+			       GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
 
-	/* Add Replace button */
-	gedit_dialog_add_button (GTK_DIALOG (msgbox), 
+	gedit_dialog_add_button (GTK_DIALOG (dialog), 
 			_("_Replace"), GTK_STOCK_REFRESH, GTK_RESPONSE_YES);
 
-	gtk_dialog_set_default_response	(GTK_DIALOG (msgbox), GTK_RESPONSE_CANCEL);
+	gtk_dialog_set_default_response	(GTK_DIALOG (dialog), GTK_RESPONSE_CANCEL);
 
-	obj = gtk_widget_get_accessible (msgbox);
-	if (GTK_IS_ACCESSIBLE (obj))
-		atk_object_set_name (obj, _("Question"));
+	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
-	ret = gtk_dialog_run (GTK_DIALOG (msgbox));
-	gtk_widget_destroy (msgbox);
+	ret = gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
 
 	return (ret == GTK_RESPONSE_YES);
 }
 
 /* Presents a confirmation dialog for whether to replace an existing file */
 static gboolean
-replace_existing_file (GtkWindow *parent, const gchar* file_name)
+replace_existing_file (GtkWindow *parent, const gchar *uri)
 {
 	return replace_dialog (parent,
-			       _("A file named \"%s\" already exists.\n"), file_name,
+			       _("A file named \"%s\" already exists.\n"), uri,
 			       _("Do you want to replace it with the "
 			         "one you are saving?"));
 }
 
 /* Presents a confirmation dialog for whether to replace a read-only file */
 static gboolean
-replace_read_only_file (GtkWindow *parent, const gchar* file_name)
+replace_read_only_file (GtkWindow *parent, const gchar *uri)
 {
 	return replace_dialog (parent,
-			       _("The file \"%s\" is read-only.\n"), file_name,
+			       _("The file \"%s\" is read-only.\n"), uri,
 			       _("Do you want to try to replace it with the "
 			         "one you are saving?"));
 }
@@ -221,7 +201,6 @@ file_exists (gchar *name)
 static gpointer
 analyze_response (GtkFileChooser *chooser, gint response)
 {
-	gchar *file_name;
 	gchar *uri;
 	gboolean enable_vfs;
 	
@@ -237,43 +216,63 @@ analyze_response (GtkFileChooser *chooser, gint response)
 
 	if (enable_vfs)
 	{
-		file_name = gtk_file_chooser_get_uri (chooser);
+		uri = gtk_file_chooser_get_uri (chooser);
 	}
 	else
 	{
+		gchar *file_name;
+
 		file_name = gtk_file_chooser_get_filename (chooser);
-	}
+		uri = file_name ? gnome_vfs_get_uri_from_local_path (file_name) : NULL;
 
-	if ((file_name == NULL) || (strlen (file_name) == 0)) 
-	{
 		g_free (file_name);
-		return NULL;
 	}
 
-	if (enable_vfs)
+	if ((uri == NULL) || (strlen (uri) == 0)) 
 	{
-		uri = g_strdup (file_name);
-	}
-	else
-	{
-		uri = gnome_vfs_get_uri_from_local_path (file_name);
+		g_free (uri);
+
+		return NULL;
 	}
 
 	if (GET_MODE (chooser) == FILESEL_OPEN_MULTI) 
 	{
-		GSList *files;
-	       
-		g_free (file_name);
+		GSList *uris = NULL;
+
 		g_free (uri);
 
 		if (enable_vfs)
-			files = gtk_file_chooser_get_uris (chooser);
+		{
+			uris = gtk_file_chooser_get_uris (chooser);
+		}
 		else
+		{
+			GSList *files;
+			GSList *l;
+
 			files = gtk_file_chooser_get_filenames (chooser);
 
+			for (l = files; l; l = l->next)
+			{
+				gchar *u;
+				gchar *file_name = (gchar *)l->data;
+
+				u = file_name ? gnome_vfs_get_uri_from_local_path (file_name) : NULL;
+
+				if (u != NULL)
+					uris = g_slist_prepend (uris, u);
+
+				g_free (file_name);
+			}
+
+			g_slist_free (files);
+
+			uris = g_slist_reverse (uris);
+		}
+
 		gtk_widget_hide (GTK_WIDGET (chooser));
 
-		return files;
+		return uris;
 	}
 	else	
 	{	
@@ -283,17 +282,15 @@ analyze_response (GtkFileChooser *chooser, gint response)
 			{
 				if (is_read_only (uri))
 				{
-					if (!replace_read_only_file (GTK_WINDOW (chooser), file_name)) 
+					if (!replace_read_only_file (GTK_WINDOW (chooser), uri)) 
 					{
-						g_free (file_name);
 						g_free (uri);
 
 						return NULL;
 					}
 				}
-				else if (!replace_existing_file (GTK_WINDOW (chooser), file_name)) 
+				else if (!replace_existing_file (GTK_WINDOW (chooser), uri)) 
 				{
-					g_free (file_name);
 					g_free (uri);
 
 					return NULL;
@@ -303,12 +300,10 @@ analyze_response (GtkFileChooser *chooser, gint response)
 
 		gtk_widget_hide (GTK_WIDGET (chooser));
 
-		g_free (uri);
-
-		return file_name;
+		return uri;
 	} 
 
-	return NULL;
+	g_return_val_if_reached (NULL);
 }
 
 static gboolean
@@ -384,7 +379,7 @@ create_gtk_selector (GtkWindow *parent,
 
 		hbox = gtk_hbox_new (FALSE, 6);
 
-		label = gtk_label_new_with_mnemonic (_("Ch_aracter Coding:"));
+		label = gtk_label_new_with_mnemonic (_("_Character Coding:"));
 		menu = gedit_encodings_option_menu_new (mode == FILESEL_SAVE);
 		
 		gtk_label_set_mnemonic_widget (GTK_LABEL (label), menu);				       		
@@ -519,8 +514,7 @@ run_file_selector (GtkWindow  *parent,
  * Creates and shows a modal open file dialog, waiting for the user to
  * select a file or cancel before returning.
  *
- * Return value: the URI (or plain file path if @enable_vfs is FALSE)
- * of the file selected, or NULL if cancel was pressed.
+ * Return value: the URI of the file selected, or NULL if cancel was pressed.
  **/
 char *
 gedit_file_selector_open (GtkWindow  *parent,
@@ -544,9 +538,8 @@ gedit_file_selector_open (GtkWindow  *parent,
  * Creates and shows a modal open file dialog, waiting for the user to
  * select a file or cancel before returning.
  *
- * Return value: a GSList list of the selected URIs 
- * (or local file paths if @enable_vfs is FALSE), 
- * or NULL if cancel was pressed.
+ * Return value: a GSList list of the selected URIs, or NULL if
+ * cancel was pressed.
  **/
 GSList *
 gedit_file_selector_open_multi (GtkWindow  *parent,
@@ -572,8 +565,8 @@ gedit_file_selector_open_multi (GtkWindow  *parent,
  * Creates and shows a modal save file dialog, waiting for the user to
  * select a file or cancel before returning.
  *
- * Return value: the URI (or plain file path if @enable_vfs is FALSE)
- * of the file selected, or NULL if cancel was pressed.
+ * Return value: the URI of the file selected, or NULL if cancel
+ * was pressed.
  **/
 char *
 gedit_file_selector_save (GtkWindow  *parent,
